# `pytesdaq`

[![PyPI](https://img.shields.io/pypi/v/pytesdaq)](https://pypi.org/project/pytesdaq/) [![Python 3.6](https://img.shields.io/badge/python-3.6+-blue.svg)](https://www.python.org/downloads/release/python-360/)

`pytesdaq` contains python data acquisition and data handling code for TES detector related R&D and dark matter searches.

To install the most recent release of `pytesdaq`, type the following line into your command line

`pip install pytesdaq --upgrade`

To install the most recent development version of `pytesdaq`, clone this repo, then from the top-level directory of the repo, type the following line into your command line

`pip install .`

If using a shared Python installation, you may want to add the `--user` flag to the above line.
